@@ -5,7 +5,7 @@ import matplotlib.pyplot as plt
 import pywt
 import scipy.signal
 from scipy import signal
-from audio_proc_functions import *
+#from audio_proc_functions import *
 from nsgt import NSGT, LogScale, LinScale, MelScale, OctScale
 #from constant_q_FB import create_filters
 import time
